Country class

Constructors

Country({required String name, required String flag, required String code, required String dialCode, required Map<String, String> nameTranslations, required int minLength, required int maxLength, String regionCode = ""})
const

Properties

code → String
final
dialCode → String
final
displayCC → String
no setter
flag → String
final
fullCountryCode → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
maxLength → int
final
minLength → int
final
name → String
final
nameTranslations → Map<String, String>
final
regionCode → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

localizedName(String languageCode) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited