MobileNumber class

Constructors

MobileNumber({required String countryISOCode, required String countryCode, required String number})
MobileNumber.fromCompleteNumber({required String completeNumber})
factory

Properties

completeNumber → String
no setter
countryCode ↔ String
getter/setter pair
countryISOCode ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
number ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValidNumber() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getCountry(String mobileNumber, [String? countryISOCode]) → Country